============
Contributors
============

This work was developed by Hippolyte Verdier `(e-mail) <hverdier@pasteur.fr>`_ during his PhD at the `Decision and Bayesian Computation lab <https://research.pasteur.fr/en/team/decision-and-bayesian-computation/>`_ at the Institut Pasteur, funded by Sanofi.

Thanks to Gert-Jan Both for precious advice on code structure and coding practices.